# Honeycomb Beeline for Python

[![OSS Lifecycle](https://img.shields.io/osslifecycle/honeycombio/beeline-python?color=success)](https://github.com/honeycombio/home/blob/main/honeycomb-oss-lifecycle-and-practices.md)
[![Build Status](https://circleci.com/gh/honeycombio/beeline-python.svg?style=svg)](https://app.circleci.com/pipelines/github/honeycombio/beeline-python)

This package makes it easy to instrument your Python web application to send useful events to [Honeycomb](https://honeycomb.io), a service for debugging your software in production.

- [Usage and Examples](https://docs.honeycomb.io/getting-data-in/beelines/beeline-python/)
- [API Reference](https://honeycombio.github.io/beeline-python/)

## Compatible with

Currently, supports Django (>2), Flask, Bottle, and Tornado.

Compatible with Python 3.

## Get in touch

Please reach out to [support@honeycomb.io](mailto:support@honeycomb.io) or ping
us with the chat bubble on [our website](https://www.honeycomb.io) for any
assistance. We also welcome [bug reports](https://github.com/honeycombio/beeline-python/issues).

## Contributions

Features, bug fixes and other changes to `beeline-python` are gladly accepted. Please
open issues or a pull request with your change. Remember to add your name to the
CONTRIBUTORS file!

If you add a new test module, be sure and update `beeline.test_suite` to pick up the new tests.

All contributions will be released under the Apache License 2.0.
